@@ -21,17 +21,20 @@ method get ($slug) {
 }
 
 method create ($slug, $content, $created = DateTime->now) {
+    my $html = App::skryf::Util->convert($content, USE_WIKILINKS);
     $self->pages->insert(
       {
             slug => $slug,
             content => $content,
             created => $created->strftime('%Y-%m-%dT%H:%M:%SZ'),
+            html => $html,
         }
     );
 }
 
 method save ($page) {
     my $lt = DateTime->now;
+    $page->{html} = App::skryf::Util->convert($page->{content}, USE_WIKILINKS);
     $page->{modified} = $lt->strftime('%Y-%m-%dT%H:%M:%SZ');
     $self->pages->save($page);
 }
